```
Usage: vcd vapp update [OPTIONS] <vapp-name>

Options:
  -n, --name <name>               new name of the vapp  [required]
  -d, --description <description>
                                  new description of the vapp
  -h, --help                      Show this message and exit.

```
